/***********************************
 This command file illustrates using
 SAS for basic data setup and
 variable creation.

filename: brieftour.sas
************************************/

OPTIONS FORMCHAR="|----|+|---+=|-/\<>*";
libname sasdata2 "C:\Users\kwelch\Desktop\sasdata2";


/*****************Read in raw data************************/
data class;
	infile "class.dat";
	input lname $ sex $ age height sbp;
run;


/*************Fixed Column Data****************************/
data flights;
	infile "marflt.dat" ;
	input flight 1-3 depart $ 15-17 dest $ 18-20 boarded 34-36;
run;


/*************Read in Excel Data***************************/
PROC IMPORT OUT=pulse 
            DATAFILE="PULSE.XLS"
            DBMS= xls REPLACE; 
            SHEET="pulse"; 
RUN;


/****************Create a permanent SAS dataset********************/
data sasdata2.flights;
	infile "marflt.dat" ;
	input flight 1-3 depart $ 15-17 dest $ 18-20 boarded 34-36;
run;
proc means data=sasdata2.flights;
run;


/*************Use a permanent SAS dataset*****************/
proc means data=sasdata2.employee;
run;

proc freq data=sasdata2.employee;
  tables gender jobcat;
run;

/*User-defined formats*/
proc format;
  value $genderfmt "f"="Female"
                   "m"="Male";
  value jobcatfmt 1="Clerical"
                  2="Custodial"
				  3="Managerial";
run;
proc freq data=sasdata2.employee;
  tables gender jobcat;
  format gender $genderfmt. jobcat jobcatfmt.;
run;
proc print data=sasdata2.employee;
  where jobcat=1;
  format bdate mmddyy10. salary salbegin dollar12. gender $genderfmt.  
         jobcat jobcatfmt.;
run;


/***********Generate new variables in a SAS dataset***************/
data sasdata2.employee2;
  set sasdata2.employee;
  currentyear=2005;
  alpha ="A"; 

  /*datevar = mdy(10,5,2012);*/ 
  datevar = "05OCT2012"D; 
  format datevar mmddyy10.;

  saldiff = salary - salbegin;
  if (salary >= 0 and salary <= 25000) then salcat = "C"; 
  if (salary > 25000 & salary <= 50000) then salcat = "B";
  if (salary > 50000) then salcat = "A";

  if salary not=. and jobcat not=. then do;
      if (salary < 50000 & jobcat = 3) then manlowsal = 1; 
      else manlowsal = 0;
  end;

  format bdate mmddyy10. salary salbegin dollar12.;

if gender="f" then female=1;
if gender="m" then female=0;

if jobcat not=. then do;
   jobdum1 = (jobcat=1);
   jobdum2 = (jobcat=2);
   jobdum3 = (jobcat=3);
end;

nmiss = nmiss(of educ--salbegin);
salmean = mean(salary, salbegin);
run;


/***********Temporary Formats*************/
proc format;
  value jobcats 1="Clerical" 2="Custodial" 3="Manager";
  value $sexfmt "f" = "Female"
                "m" = "Male";
  value minfmt  1="Yes"
                0="No";
run;
proc freq data=sasdata2.employee2;
  tables jobcat gender minority;
  format jobcat jobcats. gender $sexfmt. minority minfmt.;
run;


/**********Permanent Formats***********/
proc format lib=sasdata2;
  value jobcatfmt 1="Clerical" 2="Custodial" 3="Manager";
  value $genderfmt "f" = "Female"
                   "m" = "Male";
  value minfmt  1="Yes"
                0="No";
run;
options fmtsearch=(work sasdata2);
proc datasets lib=sasdata2;
  modify employee2;
  format jobcat jobcatfmt. gender $genderfmt. minority minfmt.;
run;
proc contents data=sasdata2.employee2;
run;

/*Use the formatted data later*/
options nofmterr;
options fmtsearch=(work sasdata2);
proc means data=sasdata2.employee2;
  class jobcat;
  var saldiff;
run;


/*********Sort data**********/
proc sort data=sasdata2.employee2;
  by gender;
run;
title "Descriptive Statistics for Each Gender";
proc means data=sasdata2.employee2;
  by gender;
run;

/*Sort by a continuous variable*/
proc sort data=sasdata2.employee2;
  by salary;
run;
proc contents data=sasdata2.employee2;
run;

/*Sort in descending order*/
proc sort data=sasdata2.employee2;
  by descending salary;
run;

/*Sort by more than one variable*/
proc sort data=sasdata2.employee2;
  by gender descending salary;
run;

/*************Descriptive Statistics*********************/
/*PROC PRINT*/
proc print data=pulse;
run;
proc print data=pulse(obs=6);
  var height weight pulse1 pulse2;
run;

/*PROC CONTENTS*/
proc contents data=pulse;
run;
proc contents data=pulse varnum;
run;


/*PROC MEANS*/
proc means data=pulse;
run;
proc means data = pulse n mean min max median p25 p75;
  var height weight pulse1;
run;
proc means data = pulse;
    class ran;
run;
options nolabel;
proc means data = pulse ;
    class ran activity;
run;

/*PROC FREQ*/
/*Oneway frequencies*/
title;
proc freq data = pulse;
   tables ran activity smokes;
run;
/*Twoway cross-tabulations*/
proc freq data = pulse;
   tables sex * activity;
run;
proc freq data = pulse;
   tables sex * activity / expected norow nocol nopercent chisq;
run;
/*Threeway Cross-tabulation*/
proc freq data = pulse;
   tables ran*sex*activity;
run;


/*PROC UNIVARIATE*/
proc univariate data = pulse plot;
   var pulse1;
   histogram;
run;
proc univariate data=pulse;
  class ran;
  var pulse2;
  histogram;
run;














